@@ -17,6 +17,12 @@ __author__ = "Justin Forest <hex@umonkey.net>"
 __license__ = "GNU LGPL"
 
 
+def chunks(l, n):
+    # http://stackoverflow.com/questions/312443/how-do-you-split-a-list-into-evenly-sized-chunks-in-python
+    for i in range(0, len(l), n):
+        yield l[i:i + n]
+
+
 class Error(Exception):
     pass
 
@@ -288,22 +294,29 @@ class Client(object):
     def GetCampaignParams(self, CampaignID):
         return self.call_method("GetCampaignParams", {"CampaignID": CampaignID})
 
-    def GetImages(self, logins=None):
-        query = {}
-        if logins:
-            query["Logins"] = logins
+    def GetImages(self, logins):
+        images = []
 
-        return self.call_method("AdImage", {
-            "Action": "Get",
-            "SelectionCriteria": query,
-        })["AdImages"]
+        for part in chunks(logins, 10):
+            res = self.call_method("AdImage", {
+                "Action": "Get",
+                "SelectionCriteria": {
+                    "Logins": part,
+                }
+            })
+            images += res["AdImages"]
+
+        return images
 
     def GetImageAssociations(self, logins=None):
-        query = {}
-        if logins:
-            query["Logins"] = logins
+        result = []
 
-        return self.call_method("AdImageAssociation", {
-            "Action": "Get",
-            "SelectionCriteria": query,
-        })["AdImageAssociations"]
+        for part in chunks(logins, 10):
+            result += self.call_method("AdImageAssociation", {
+                "Action": "Get",
+                "SelectionCriteria": {
+                    "Logins": part,
+                },
+            })["AdImageAssociations"]
+
+        return result
